package org.apache.commons.lang3;

import org.apache.commons.lang3.math.NumberUtils;

/* loaded from: org_apache_commons_lang3.jar:org/apache/commons/lang3/JavaVersion.class */
public enum JavaVersion {
    JAVA_0_9(1.5f, "0.9"),
    JAVA_1_1(1.1f, "1.1"),
    JAVA_1_2(1.2f, "1.2"),
    JAVA_1_3(1.3f, "1.3"),
    JAVA_1_4(1.4f, "1.4"),
    JAVA_1_5(1.5f, "1.5"),
    JAVA_1_6(1.6f, "1.6"),
    JAVA_1_7(1.7f, "1.7"),
    JAVA_1_8(1.8f, "1.8"),
    JAVA_1_9(9.0f, "9"),
    JAVA_9(9.0f, "9"),
    JAVA_10(10.0f, "10"),
    JAVA_11(11.0f, "11"),
    JAVA_12(12.0f, "12"),
    JAVA_13(13.0f, "13"),
    JAVA_14(14.0f, "14"),
    JAVA_15(15.0f, "15"),
    JAVA_16(16.0f, "16"),
    JAVA_17(17.0f, "17"),
    JAVA_RECENT(maxVersion(), Float.toString(maxVersion()));

    private final float value;
    private final String name;

    JavaVersion(float value, String name) {
        this.value = value;
        this.name = name;
    }

    public boolean atLeast(JavaVersion requiredVersion) {
        return this.value >= requiredVersion.value;
    }

    public boolean atMost(JavaVersion requiredVersion) {
        return this.value <= requiredVersion.value;
    }

    static JavaVersion getJavaVersion(String nom) {
        return get(nom);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static JavaVersion get(String versionStr) {
        if (versionStr == null) {
            return null;
        }
        boolean z = -1;
        switch (versionStr.hashCode()) {
            case 57:
                if (versionStr.equals("9")) {
                    z = 9;
                    break;
                }
                break;
            case 1567:
                if (versionStr.equals("10")) {
                    z = 10;
                    break;
                }
                break;
            case 1568:
                if (versionStr.equals("11")) {
                    z = 11;
                    break;
                }
                break;
            case 1569:
                if (versionStr.equals("12")) {
                    z = 12;
                    break;
                }
                break;
            case 1570:
                if (versionStr.equals("13")) {
                    z = 13;
                    break;
                }
                break;
            case 1571:
                if (versionStr.equals("14")) {
                    z = 14;
                    break;
                }
                break;
            case 1572:
                if (versionStr.equals("15")) {
                    z = 15;
                    break;
                }
                break;
            case 1573:
                if (versionStr.equals("16")) {
                    z = 16;
                    break;
                }
                break;
            case 1574:
                if (versionStr.equals("17")) {
                    z = 17;
                    break;
                }
                break;
            case 47611:
                if (versionStr.equals("0.9")) {
                    z = false;
                    break;
                }
                break;
            case 48564:
                if (versionStr.equals("1.1")) {
                    z = true;
                    break;
                }
                break;
            case 48565:
                if (versionStr.equals("1.2")) {
                    z = 2;
                    break;
                }
                break;
            case 48566:
                if (versionStr.equals("1.3")) {
                    z = 3;
                    break;
                }
                break;
            case 48567:
                if (versionStr.equals("1.4")) {
                    z = 4;
                    break;
                }
                break;
            case 48568:
                if (versionStr.equals("1.5")) {
                    z = 5;
                    break;
                }
                break;
            case 48569:
                if (versionStr.equals("1.6")) {
                    z = 6;
                    break;
                }
                break;
            case 48570:
                if (versionStr.equals("1.7")) {
                    z = 7;
                    break;
                }
                break;
            case 48571:
                if (versionStr.equals("1.8")) {
                    z = 8;
                    break;
                }
                break;
        }
        switch (z) {
            case CharUtils.NUL /* 0 */:
                return JAVA_0_9;
            case true:
                return JAVA_1_1;
            case true:
                return JAVA_1_2;
            case true:
                return JAVA_1_3;
            case true:
                return JAVA_1_4;
            case true:
                return JAVA_1_5;
            case true:
                return JAVA_1_6;
            case true:
                return JAVA_1_7;
            case true:
                return JAVA_1_8;
            case true:
                return JAVA_9;
            case CharUtils.LF /* 10 */:
                return JAVA_10;
            case true:
                return JAVA_11;
            case true:
                return JAVA_12;
            case CharUtils.CR /* 13 */:
                return JAVA_13;
            case true:
                return JAVA_14;
            case true:
                return JAVA_15;
            case true:
                return JAVA_16;
            case true:
                return JAVA_17;
            default:
                float v = toFloatVersion(versionStr);
                if (v - 1.0d >= 1.0d) {
                    if (v > 10.0f) {
                        return JAVA_RECENT;
                    }
                    return null;
                }
                int firstComma = Math.max(versionStr.indexOf(46), versionStr.indexOf(44));
                int end = Math.max(versionStr.length(), versionStr.indexOf(44, firstComma));
                if (Float.parseFloat(versionStr.substring(firstComma + 1, end)) > 0.9f) {
                    return JAVA_RECENT;
                }
                return null;
        }
    }

    @Override // java.lang.Enum
    public String toString() {
        return this.name;
    }

    private static float maxVersion() {
        float v = toFloatVersion(System.getProperty("java.specification.version", "99.0"));
        if (v > 0.0f) {
            return v;
        }
        return 99.0f;
    }

    private static float toFloatVersion(String value) {
        if (value.contains(".")) {
            String[] toParse = value.split("\\.");
            if (toParse.length >= 2) {
                return NumberUtils.toFloat(toParse[0] + '.' + toParse[1], -1.0f);
            }
            return -1.0f;
        }
        return NumberUtils.toFloat(value, -1.0f);
    }
}
